$.jqplot.CanvasAxisTickRenderer

Renderer to draw axis ticks with a canvas element to support advanced featrues such as rotated text. This renderer uses a separate rendering engine to draw the text on the canvas. Two modes of rendering the text are available. If the browser has native font support for canvas fonts (currently Mozila 3.5 and Safari 4), you can enable text rendering with the canvas fillText method. You do so by setting the “enableFontSupport” option to true.

Browsers lacking native font support will have the text drawn on the canvas using the Hershey font metrics. Even if the “enableFontSupport” option is true non-supporting browsers will still render with the Hershey font.

Summary

$.jqplot.CanvasAxisTickRenderer | Renderer to draw axis ticks with a canvas element to support advanced featrues such as rotated text.
Properties |
mark | tick mark on the axis.
showMark | whether or not to show the mark on the axis.
showGridline | whether or not to draw the gridline on the grid at this tick.
isMinorTick | if this is a minor tick.
angle | angle of text, measured clockwise from x axis.
markSize | Length of the tick marks in pixels.
show | whether or not to show the tick (mark and label).
showLabel | whether or not to show the label.
labelPosition | ‘auto’, ‘start’, ‘middle’ or ‘end’.
formatter | A class of a formatter for the tick text.
formatString | string passed to the formatter.
prefix | String to prepend to the tick label.
fontFamily | css spec for the font-family css attribute.
fontSize | CSS spec for font size.
fontWeight | CSS spec for fontWeight
fontStretch | Multiplier to condense or expand font width.
textColor | css spec for the color attribute.
enableFontSupport | true to turn on native canvas font support in Mozilla 3.5+ and Safari 4+.
pt2px | Point to pixel scaling factor, used for computing height of bounding box around a label.

### Properties

### mark

> this.mark = 'outside'

tick mark on the axis. One of ‘inside’, ‘outside’, ‘cross’, ‘’ or null.

### showMark

> this.showMark = true

whether or not to show the mark on the axis.

### showGridline

> this.showGridline = true

whether or not to draw the gridline on the grid at this tick.

### isMinorTick

> this.isMinorTick = false

if this is a minor tick.

### angle

> this.angle = 0

angle of text, measured clockwise from x axis.

### markSize

> this.markSize = 4

Length of the tick marks in pixels. For ‘cross’ style, length will be stoked above and below axis, so total length will be twice this.

### show

> this.show = true

whether or not to show the tick (mark and label).

### showLabel

> this.showLabel = true

whether or not to show the label.

### labelPosition

> this.labelPosition = 'auto'

’auto’, ‘start’, ‘middle’ or ‘end’. Whether tick label should be positioned so the start, middle, or end of the tick mark.

### formatter

> this.formatter = $.jqplot.DefaultTickFormatter

A class of a formatter for the tick text. The default $.jqplot.DefaultTickFormatter uses sprintf.

### formatString

> this.formatString = ''

string passed to the formatter.

### prefix

> this.prefix = ''

String to prepend to the tick label. Prefix is prepended to the formatted tick label.

### fontFamily

> this.fontFamily = '"Trebuchet MS", Arial, Helvetica, sans-serif'

css spec for the font-family css attribute.

### fontSize

> this.fontSize = '10pt'

CSS spec for font size.

### fontWeight

> this.fontWeight = 'normal'

CSS spec for fontWeight

### fontStretch

> this.fontStretch = 1.0

Multiplier to condense or expand font width. Applies only to browsers which don’t support canvas native font rendering.

### textColor

> this.textColor = '#666666'

css spec for the color attribute.

### enableFontSupport

> this.enableFontSupport = true

true to turn on native canvas font support in Mozilla 3.5+ and Safari 4+. If true, tick label will be drawn with canvas tag native support for fonts. If false, tick label will be drawn with Hershey font metrics.

### pt2px

> this.pt2px = null

Point to pixel scaling factor, used for computing height of bounding box around a label. The labels text renderer has a default setting of 1.4, which should be suitable for most fonts. Leave as null to use default. If tops of letters appear clipped, increase this. If bounding box seems too big, decrease. This is an issue only with the native font renderering capabilities of Mozilla 3.5 and Safari 4 since they do not provide a method to determine the font height.

> this.mark = 'outside'

tick mark on the axis.

> this.showMark = true

whether or not to show the mark on the axis.

> this.showGridline = true

whether or not to draw the gridline on the grid at this tick.

> this.isMinorTick = false

if this is a minor tick.

> this.angle = 0

angle of text, measured clockwise from x axis.

> this.markSize = 4

Length of the tick marks in pixels.

> this.show = true

whether or not to show the tick (mark and label).

> this.showLabel = true

whether or not to show the label.

> this.labelPosition = 'auto'

‘auto’, ‘start’, ‘middle’ or ‘end’.

> this.formatter = $.jqplot.DefaultTickFormatter

A class of a formatter for the tick text.

> this.formatString = ''

string passed to the formatter.

> this.prefix = ''

String to prepend to the tick label.

> this.fontFamily = '"Trebuchet MS", Arial, Helvetica, sans-serif'

css spec for the font-family css attribute.

> this.fontSize = '10pt'

CSS spec for font size.

> this.fontWeight = 'normal'

CSS spec for fontWeight

> this.fontStretch = 1.0

Multiplier to condense or expand font width.

> this.textColor = '#666666'

css spec for the color attribute.

> this.enableFontSupport = true

true to turn on native canvas font support in Mozilla 3.5+ and Safari 4+.

> this.pt2px = null

Point to pixel scaling factor, used for computing height of bounding box around a label.
Close